<template>
  <el-bus-crud v-bind="tableConfig" />
</template>

<script>
export default {
  data() {
    return {
      tableConfig: {
        url: 'flower/api/partner/page',
        hasEdit: false,
        hasNew: false,
        hasDelete: false,
        hasView: false,
        extraQuery: {
          status: 'P',
          isEnabled: 1,
        },
        operationAttrs: {
          width: 150,
          fixed: 'right',
        },
        columns: [
          { label: '合伙人名称', prop: 'name', minWidth: 120, fixed: 'left' },
          {
            label: '服务地区',
            formatter: (row) => this.getDistrict(row),
            minWidth: 200,
          },
          {
            label: '联系方式',
            prop: 'contactTel',
            minWidth: 150,
          },
          { label: '注册时间', prop: 'createTime', minWidth: '180px' },
        ],
        searchForm: [
          {
            type: 'row',
            items: [
              {
                label: '合伙人名称',
                id: 'name',
                type: 'input',
              },
              {
                label: '手机号',
                id: 'tel',
                type: 'input',
              },
              {
                label: '申请日期',
                component: 'el-bus-date-range',
                id: 'createDateBeginStr',
                commonFormat: true,
                commonFormatProps: ['createDateBeginStr', 'createDateEndStr'],
                customClass: 'in-bus-form',
              },
              {
                label: '服务地区',
                id: 'province',
                component: 'el-bus-select-area',
                el: {
                  clearable: true,
                },
                commonFormat: true,
                commonFormatProps: ['province', 'city', 'region'],
                customClass: 'in-bus-form',
              },
            ],
          },
        ],
        extraButtons: [
          {
            text: '分类加价',
            atClick: (row) => {
              const url = this.$router.resolve(
                `${this.$route.path}/${row.id}/category?partnerName=${row.name}`
              ).href
              window.open(url, '_blank')
            },
          },
          {
            text: '商品加价',
            atClick: (row) => {
              const url = this.$router.resolve(
                `${this.$route.path}/${row.id}/goods?partnerName=${row.name}`
              ).href
              window.open(url, '_blank')
            },
          },
        ],
      },
    }
  },
  head() {
    return {
      title: '合伙人加价',
    }
  },
  methods: {
    getDistrict(row) {
      if (row.province) {
        return row.province
          .split(',')
          .map((item, index) =>
            [
              item,
              row.city.split(',')[index],
              row.region.split(',')[index],
            ].join('-')
          )
          .join(',')
      }
      return ''
    },
  },
}
</script>

<style lang="scss" scoped></style>
